==> dagger-compiler-2.47-sources.jar: dagger/internal/codegen/binding/AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XMethodElement;
import androidx.room.compiler.processing.XMethodType;
import androidx.room.compiler.processing.XType;
import androidx.room.compiler.processing.XTypeElement;
import androidx.room.compiler.processing.XVariableElement;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import com.google.errorprone.annotations.concurrent.LazyInit;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata extends $AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XVariableElement> assistedInjectAssistedParametersMap;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XVariableElement> assistedFactoryAssistedParametersMap;

  AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata(XTypeElement factory$,
      XType factoryType$, XMethodElement factoryMethod$, XMethodType factoryMethodType$,
      XTypeElement assistedInjectElement$, XType assistedInjectType$,
      ImmutableList<AssistedInjectionAnnotations.AssistedParameter> assistedInjectAssistedParameters$,
      ImmutableList<AssistedInjectionAnnotations.AssistedParameter> assistedFactoryAssistedParameters$) {
    super(factory$, factoryType$, factoryMethod$, factoryMethodType$, assistedInjectElement$, assistedInjectType$, assistedInjectAssistedParameters$, assistedFactoryAssistedParameters$);
  }

  @Override
  public ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XVariableElement> assistedInjectAssistedParametersMap() {
    if (assistedInjectAssistedParametersMap == null) {
      synchronized (this) {
        if (assistedInjectAssistedParametersMap == null) {
          assistedInjectAssistedParametersMap = super.assistedInjectAssistedParametersMap();
          if (assistedInjectAssistedParametersMap == null) {
            throw new NullPointerException("assistedInjectAssistedParametersMap() cannot return null");
          }
        }
      }
    }
    return assistedInjectAssistedParametersMap;
  }

  @Override
  public ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XVariableElement> assistedFactoryAssistedParametersMap() {
    if (assistedFactoryAssistedParametersMap == null) {
      synchronized (this) {
        if (assistedFactoryAssistedParametersMap == null) {
          assistedFactoryAssistedParametersMap = super.assistedFactoryAssistedParametersMap();
          if (assistedFactoryAssistedParametersMap == null) {
            throw new NullPointerException("assistedFactoryAssistedParametersMap() cannot return null");
          }
        }
      }
    }
    return assistedFactoryAssistedParametersMap;
  }
}

==> dagger-compiler-2.51.1-sources.jar: dagger/internal/codegen/binding/AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata.java <==
package dagger.internal.codegen.binding;

import androidx.room.compiler.processing.XExecutableParameterElement;
import androidx.room.compiler.processing.XMethodElement;
import androidx.room.compiler.processing.XMethodType;
import androidx.room.compiler.processing.XType;
import androidx.room.compiler.processing.XTypeElement;
import com.google.common.collect.ImmutableList;
import com.google.common.collect.ImmutableMap;
import com.google.errorprone.annotations.concurrent.LazyInit;
import java.lang.Override;
import java.lang.SuppressWarnings;

final class AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata extends $AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata {
  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XExecutableParameterElement> assistedInjectAssistedParametersMap;

  @LazyInit
  @SuppressWarnings("Immutable")
  private transient volatile ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XExecutableParameterElement> assistedFactoryAssistedParametersMap;

  AutoValue_AssistedInjectionAnnotations_AssistedFactoryMetadata(XTypeElement factory$,
      XType factoryType$, XMethodElement factoryMethod$, XMethodType factoryMethodType$,
      XTypeElement assistedInjectElement$, XType assistedInjectType$,
      ImmutableList<AssistedInjectionAnnotations.AssistedParameter> assistedInjectAssistedParameters$,
      ImmutableList<AssistedInjectionAnnotations.AssistedParameter> assistedFactoryAssistedParameters$) {
    super(factory$, factoryType$, factoryMethod$, factoryMethodType$, assistedInjectElement$, assistedInjectType$, assistedInjectAssistedParameters$, assistedFactoryAssistedParameters$);
  }

  @Override
  public ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XExecutableParameterElement> assistedInjectAssistedParametersMap() {
    if (assistedInjectAssistedParametersMap == null) {
      synchronized (this) {
        if (assistedInjectAssistedParametersMap == null) {
          assistedInjectAssistedParametersMap = super.assistedInjectAssistedParametersMap();
          if (assistedInjectAssistedParametersMap == null) {
            throw new NullPointerException("assistedInjectAssistedParametersMap() cannot return null");
          }
        }
      }
    }
    return assistedInjectAssistedParametersMap;
  }

  @Override
  public ImmutableMap<AssistedInjectionAnnotations.AssistedParameter, XExecutableParameterElement> assistedFactoryAssistedParametersMap() {
    if (assistedFactoryAssistedParametersMap == null) {
      synchronized (this) {
        if (assistedFactoryAssistedParametersMap == null) {
          assistedFactoryAssistedParametersMap = super.assistedFactoryAssistedParametersMap();
          if (assistedFactoryAssistedParametersMap == null) {
            throw new NullPointerException("assistedFactoryAssistedParametersMap() cannot return null");
          }
        }
      }
    }
    return assistedFactoryAssistedParametersMap;
  }
}
